@@ -51,12 +51,16 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/cpu_mode').with_value('host-model')}
       it { is_expected.to contain_nova_config('libvirt/cpu_models').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/cpu_model_extra_flags').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_power_management').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_power_management_strategy').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_power_governor_low').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_power_governor_high').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/snapshot_image_format').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/snapshots_directory').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/disk_cachemodes').with_ensure('absent')}
-      it { is_expected.to contain_nova_config('libvirt/inject_password').with_value(false)}
-      it { is_expected.to contain_nova_config('libvirt/inject_key').with_value(false)}
-      it { is_expected.to contain_nova_config('libvirt/inject_partition').with_value(-2)}
+      it { is_expected.to contain_nova_config('libvirt/inject_password').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/inject_key').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/inject_partition').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/enabled_perf_events').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/sysinfo_serial').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/device_detach_attempts').with_value('<SERVICE DEFAULT>')}
@@ -64,6 +68,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('vnc/server_listen').with_value('127.0.0.1')}
       it { is_expected.to contain_nova_config('libvirt/rx_queue_size').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/tx_queue_size').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/file_backed_memory').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/images_type').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/volume_use_multipath').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_value('<SERVICE DEFAULT>')}
@@ -75,10 +80,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/swtpm_group').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/max_queues').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/num_memory_encrypted_guests').with_value('<SERVICE DEFAULT>')}
-      it { is_expected.to contain_libvirtd_config('log_outputs').with_value('<SERVICE DEFAULT>').with_quote(true)}
-      it { is_expected.to contain_libvirtd_config('log_filters').with_value('<SERVICE DEFAULT>').with_quote(true)}
-      it { is_expected.to contain_libvirtd_config('tls_priority').with_value('<SERVICE DEFAULT>').with_quote(true)}
-      it { is_expected.to contain_libvirtd_config('ovs_timeout').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/wait_soft_reboot_seconds').with_value('<SERVICE DEFAULT>')}
     end
 
     describe 'with params' do
@@ -89,6 +91,10 @@ describe 'nova::compute::libvirt' do
           :cpu_mode                                   => 'host-passthrough',
           :cpu_models                                 => ['kvm64', 'qemu64'],
           :cpu_model_extra_flags                      => 'pcid',
+          :cpu_power_management                       => false,
+          :cpu_power_management_strategy              => 'cpu_state',
+          :cpu_power_governor_low                     => 'powersave',
+          :cpu_power_governor_high                    => 'performance',
           :snapshot_image_format                      => 'raw',
           :snapshots_directory                        => '/var/lib/nova/snapshots',
           :disk_cachemodes                            => ['file=directsync','block=none'],
@@ -105,6 +111,7 @@ describe 'nova::compute::libvirt' do
           :preallocate_images                         => 'space',
           :rx_queue_size                              => 512,
           :tx_queue_size                              => 1024,
+          :file_backed_memory                         => 2048,
           :images_type                                => 'raw',
           :volume_use_multipath                       => false,
           :nfs_mount_options                          => 'rw,intr,nolock',
@@ -114,13 +121,9 @@ describe 'nova::compute::libvirt' do
           :swtpm_enabled                              => true,
           :swtpm_user                                 => 'libvirt',
           :swtpm_group                                => 'libvirt',
-          :log_outputs                                => '1:file:/var/log/libvirt/libvirtd.log',
-          :log_filters                                => '1:qemu',
-          :tls_priority                               => 'NORMAL:-VERS-SSL3.0',
-          :ovs_timeout                                => 10,
           :max_queues                                 => 4,
           :num_memory_encrypted_guests                => 255,
-          :modular_libvirt                            => true,
+          :wait_soft_reboot_seconds                   => 120,
         }
       end
 
@@ -134,6 +137,10 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/cpu_mode').with_value('host-passthrough')}
       it { is_expected.to contain_nova_config('libvirt/cpu_models').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/cpu_model_extra_flags').with_value('pcid')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_power_management').with_value(false)}
+      it { is_expected.to contain_nova_config('libvirt/cpu_power_management_strategy').with_value('cpu_state')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_power_governor_low').with_value('powersave')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_power_governor_high').with_value('performance')}
       it { is_expected.to contain_nova_config('libvirt/snapshot_image_format').with_value('raw')}
       it { is_expected.to contain_nova_config('libvirt/snapshots_directory').with_value('/var/lib/nova/snapshots')}
       it { is_expected.to contain_nova_config('libvirt/disk_cachemodes').with_value('file=directsync,block=none')}
@@ -146,6 +153,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('vnc/server_listen').with_value('0.0.0.0')}
       it { is_expected.to contain_nova_config('libvirt/rx_queue_size').with_value(512)}
       it { is_expected.to contain_nova_config('libvirt/tx_queue_size').with_value(1024)}
+      it { is_expected.to contain_nova_config('libvirt/file_backed_memory').with_value(2048)}
       it { is_expected.to contain_nova_config('libvirt/images_type').with_value('raw')}
       it { is_expected.to contain_nova_config('libvirt/volume_use_multipath').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_value('rw,intr,nolock')}
@@ -157,6 +165,8 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/swtpm_group').with_value('libvirt')}
       it { is_expected.to contain_nova_config('libvirt/max_queues').with_value(4)}
       it { is_expected.to contain_nova_config('libvirt/num_memory_encrypted_guests').with_value(255)}
+      it { is_expected.to contain_nova_config('libvirt/wait_soft_reboot_seconds').with_value(120)}
+
       it {
         is_expected.to contain_service('libvirt').with(
           :name   => 'custom_service',
@@ -277,9 +287,9 @@ describe 'nova::compute::libvirt' do
 
       it { is_expected.to contain_nova_config('DEFAULT/compute_driver').with_value('libvirt.LibvirtDriver')}
       it { is_expected.to contain_nova_config('libvirt/virt_type').with_value('kvm')}
-      it { is_expected.to contain_nova_config('libvirt/inject_password').with_value(false)}
-      it { is_expected.to contain_nova_config('libvirt/inject_key').with_value(false)}
-      it { is_expected.to contain_nova_config('libvirt/inject_partition').with_value(-2)}
+      it { is_expected.to contain_nova_config('libvirt/inject_password').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/inject_key').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/inject_partition').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('vnc/server_listen').with_value('127.0.0.1')}
       it { is_expected.to contain_nova_config('libvirt/enabled_perf_events').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/device_detach_attempts').with_value('<SERVICE DEFAULT>')}
@@ -361,7 +371,7 @@ describe 'nova::compute::libvirt' do
         facts.merge!(OSDefaults.get_facts())
       end
 
-      case facts[:osfamily]
+      case facts[:os]['family']
       when 'Debian'
         it_behaves_like 'debian-nova-compute-libvirt'
       when 'RedHat'
