@@ -19,8 +19,6 @@ describe 'nova::scheduler' do
 
     it { is_expected.to contain_nova_config('scheduler/workers').with_value(4) }
     it { is_expected.to contain_nova_config('scheduler/max_attempts').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_nova_config('scheduler/periodic_task_interval').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_nova_config('scheduler/driver').with_ensure('absent') }
     it { is_expected.to contain_nova_config('scheduler/discover_hosts_in_cells_interval').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_nova_config('scheduler/query_placement_for_image_type_support').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_nova_config('scheduler/limit_tenants_to_placement_aggregate').with_value('<SERVICE DEFAULT>') }
@@ -34,11 +32,11 @@ describe 'nova::scheduler' do
 
     context 'with manage_service as false' do
       let :params do
-        { :enabled        => true,
+        {
           :manage_service => false
         }
       end
-      it { is_expected.to contain_service('nova-scheduler').without_ensure }
+      it { is_expected.to_not contain_service('nova-scheduler') }
     end
 
     context 'with package version' do
@@ -67,22 +65,6 @@ describe 'nova::scheduler' do
       it { is_expected.to contain_nova_config('scheduler/max_attempts').with_value(10) }
     end
 
-    context 'with periodic_task_interval' do
-      let :params do
-        { :periodic_task_interval => 300 }
-      end
-
-      it { is_expected.to contain_nova_config('scheduler/periodic_task_interval').with_value(300) }
-    end
-
-    context 'with scheduler driver' do
-      let :params do
-        { :scheduler_driver => 'custom driver' }
-      end
-
-      it { is_expected.to contain_nova_config('scheduler/driver').with_value('custom driver') }
-    end
-
     context 'with discover_hosts_in_cells_interval' do
       let :params do
         { :discover_hosts_in_cells_interval => 15 }
@@ -147,33 +129,6 @@ describe 'nova::scheduler' do
       it { is_expected.to contain_nova_config('scheduler/query_placement_for_routed_network_aggregates').with_value(true) }
     end
 
-    context 'with default database parameters' do
-      let :pre_condition do
-        "include nova::db"
-      end
-
-      it { is_expected.to_not contain_nova_config('database/connection') }
-      it { is_expected.to_not contain_nova_config('database/slave_connection') }
-      it { is_expected.to_not contain_nova_config('database/connection_recycle_time').with_value('<SERVICE DEFAULT>') }
-    end
-
-    context 'with overridden database parameters' do
-      let :pre_condition do
-        "class { 'nova::db':
-           database_connection              => 'mysql://user:pass@db/db',
-           slave_connection                 => 'mysql://user:pass@slave/db',
-           database_connection_recycle_time => '30',
-         }
-        "
-      end
-
-      it { is_expected.to contain_oslo__db('nova_config').with(
-        :connection              => 'mysql://user:pass@db/db',
-        :slave_connection        => 'mysql://user:pass@slave/db',
-        :connection_recycle_time => '30',
-      )}
-    end
-
   end
 
   on_supported_os({
@@ -185,7 +140,7 @@ describe 'nova::scheduler' do
       end
 
       let (:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :scheduler_package_name => 'nova-scheduler',
             :scheduler_service_name => 'nova-scheduler' }
